Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(499)

Unified Diff: components/sync/core_impl/attachments/on_disk_attachment_store.cc

Issue 2388673002: Revert of [Sync] Move //components/sync to the syncer namespace. (patchset #5 id:40001 of https://co (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/core_impl/attachments/on_disk_attachment_store.cc
diff --git a/components/sync/core_impl/attachments/on_disk_attachment_store.cc b/components/sync/core_impl/attachments/on_disk_attachment_store.cc
index 5294638bb53465a70e1823eca5efeaaca2b74b27..90a3af33fe9d82c2f284b7225c2dddf14cdb560d 100644
--- a/components/sync/core_impl/attachments/on_disk_attachment_store.cc
+++ b/components/sync/core_impl/attachments/on_disk_attachment_store.cc
@@ -42,10 +42,10 @@ const int32_t kCurrentSchemaVersion = 1;
const base::FilePath::CharType kLeveldbDirectory[] =
FILE_PATH_LITERAL("leveldb");
// Converts AttachmentStore::Component values into
// attachment_store_pb::RecordMetadata::Component.
attachment_store_pb::RecordMetadata::Component ComponentToProto(
- AttachmentStore::Component component) {
+ syncer::AttachmentStore::Component component) {
switch (component) {
case AttachmentStore::MODEL_TYPE:
return attachment_store_pb::RecordMetadata::MODEL_TYPE;
@@ -42,10 +42,10 @@ const int32_t kCurrentSchemaVersion = 1;
const base::FilePath::CharType kLeveldbDirectory[] =
FILE_PATH_LITERAL("leveldb");
-// Converts AttachmentStore::Component values into
+// Converts syncer::AttachmentStore::Component values into
// attachment_store_pb::RecordMetadata::Component.
attachment_store_pb::RecordMetadata::Component ComponentToProto(

Powered by Google App Engine
This is Rietveld 408576698